Crate hamelin_datafusion

Crate hamelin_datafusion 

Translate Hamelin IR to DataFusion LogicalPlans

This crate provides translation from Hamelin’s lowered intermediate representation (IR) to DataFusion’s logical plan representation, enabling direct execution of Hamelin queries on DataFusion without SQL string generation.

Re-exports

pub use statement::TranslatedStatement;

Modules

arrow
codec
Codec functions for serializing/deserializing Hamelin UDFs in DataFusion plans.
statement
Statement translation from Hamelin IR to DataFusion LogicalPlan

Functions

catalog_provider_from_session
Build a Hamelin EnvironmentProvider from a DataFusion SessionContext by enumerating all registered tables and converting their Arrow schemas to Hamelin types.
parse_and_translate
Parse, type-check, and translate a Hamelin query string to a DataFusion LogicalPlan in one step.
parse_and_translate_with_options
Parse, type-check, and translate a Hamelin query string to a DataFusion LogicalPlan with full configurable options.
parse_and_translate_with_time_range
Parse, type-check, and translate a Hamelin query string to a DataFusion LogicalPlan with an injected time range expression.
translate
Translate a type-checked Hamelin AST into a DataFusion LogicalPlan.
translate_with_options
Translate a type-checked Hamelin AST into a DataFusion LogicalPlan with configurable options.
type_check_and_translate
Type-check a parsed Hamelin AST and translate it to a DataFusion LogicalPlan.
type_check_and_translate_with_options
Type-check a parsed Hamelin AST and translate it to a DataFusion LogicalPlan with full configurable options.