Translate Hamelin IR to DataFusion LogicalPlans
This crate provides translation from Hamelin’s lowered intermediate representation (IR) to DataFusion’s logical plan representation, enabling direct execution of Hamelin queries on DataFusion without SQL string generation.
Re-exports
pub use statement::TranslatedStatement;
Modules
- arrow
- codec
- Codec functions for serializing/deserializing Hamelin UDFs in DataFusion plans.
- statement
- Statement translation from Hamelin IR to DataFusion LogicalPlan
Functions
- catalog_
provider_ from_ session - Build a Hamelin
EnvironmentProviderfrom a DataFusionSessionContextby enumerating all registered tables and converting their Arrow schemas to Hamelin types. - parse_
and_ translate - Parse, type-check, and translate a Hamelin query string to a DataFusion LogicalPlan in one step.
- parse_
and_ translate_ with_ options - Parse, type-check, and translate a Hamelin query string to a DataFusion LogicalPlan with full configurable options.
- parse_
and_ translate_ with_ time_ range - Parse, type-check, and translate a Hamelin query string to a DataFusion LogicalPlan with an injected time range expression.
- translate
- Translate a type-checked Hamelin AST into a DataFusion LogicalPlan.
- translate_
with_ options - Translate a type-checked Hamelin AST into a DataFusion LogicalPlan with configurable options.
- type_
check_ and_ translate - Type-check a parsed Hamelin AST and translate it to a DataFusion LogicalPlan.
- type_
check_ and_ translate_ with_ options - Type-check a parsed Hamelin AST and translate it to a DataFusion LogicalPlan with full configurable options.